changeset 256:d9603e12a356

Corrected some spelling mistakes. git-svn-id: svn://svn.code.sf.net/p/universalindent/code/trunk@470 59b1889a-e5ac-428c-b0c7-476e01d41282
author thomas_-_s <thomas_-_s@59b1889a-e5ac-428c-b0c7-476e01d41282>
date Sat, 06 Oct 2007 10:55:05 +0000
parents 9476834349f3
children f711e521754d
files src/updatecheckdialog.cpp
diffstat 1 files changed, 5 insertions(+), 5 deletions(-) [+]
line wrap: on
line diff
--- a/src/updatecheckdialog.cpp	Sat Oct 06 10:54:31 2007 +0000
+++ b/src/updatecheckdialog.cpp	Sat Oct 06 10:55:05 2007 +0000
@@ -94,14 +94,14 @@
 
 /*!
     \brief This slot is called after the update check has returned, either by successfully
-    retreiving the pad file, or on any kind of network error.
+    retrieving the pad file, or on any kind of network error.
     
     Shows a message if check was successful or not. Offers the user to go to the 
     download page if a newer version exists. In case of an error during update
     check, a message box with the error will be displayed.
  */
 void UpdateCheckDialog::checkForUpdatedReturned(bool errorOccurred) {
     // Stop the progressbar timer.
     updateCheckProgressTimer->stop();
 
     if ( !errorOccurred ) {
@@ -117,7 +117,7 @@
             returnedString = returnedString.mid( leftPosition+17, rightPosition-(leftPosition+17) );
 
             // Only show update dialog, if the current version string is not equal to the received one.
-            if ( returnedString == currentVersion ) {
+            if ( returnedString != currentVersion ) {
                 // Show message box whether to download the new version.
                 showNewVersionAvailableDialog(returnedString);
 
@@ -148,8 +148,8 @@
 /*!
     \brief Displays the progress bar during update check.
 
-    For displaying activity during update check, a timer is startet to
-    updated the progressbar. The user can press a cancel button to
+    For displaying activity during update check, a timer is started to
+    updated the progress bar. The user can press a cancel button to
     stop the update check.
  */
 void UpdateCheckDialog::showCheckingForUpdateDialog() {
@@ -94,14 +94,14 @@
  */
 void UpdateCheckDialog::checkForUpdatedReturned(bool errorOccurred) {
-    // Stop the progressbar timer.
+    // Stop the progress bar timer.
     updateCheckProgressTimer->stop();
 